"""Modify datatype for metadata

Revision ID: 8231fee9a210
Revises: 3dce903da79a
Create Date: 2019-11-25 10:32:29.831130+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "8231fee9a210"
down_revision = "3dce903da79a"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.alter_column("python_package_metadata", "author", type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column("python_package_metadata", "author_email", type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column("python_package_metadata", "download_url", type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column("python_package_metadata", "home_page", type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column("python_package_metadata", "keywords", type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column("python_package_metadata", "license", type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column("python_package_metadata", "maintainer", type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column("python_package_metadata", "maintainer_email", type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column("python_package_metadata", "metadata_version", type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column("python_package_metadata", "name", type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column("python_package_metadata", "summary", type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column("python_package_metadata", "version", type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column("python_package_metadata", "requires_python", type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column("python_package_metadata", "description", type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column("python_package_metadata", "description_content_type", type_=sa.Text, existing_type=sa.VARCHAR)

    op.alter_column("python_package_metadata_classifier", "classifier", type_=sa.Text, existing_type=sa.VARCHAR)

    op.alter_column("python_package_metadata_platform", "platform", type_=sa.Text, existing_type=sa.VARCHAR)

    op.alter_column(
        "python_package_metadata_supported_platform", "supported_platform", type_=sa.Text, existing_type=sa.VARCHAR
    )

    op.alter_column("python_package_metadata_requires_external", "dependency", type_=sa.Text, existing_type=sa.VARCHAR)

    op.alter_column("python_package_metadata_project_url", "project_url", type_=sa.Text, existing_type=sa.VARCHAR)

    op.alter_column(
        "python_package_metadata_provides_extra", "optional_feature", type_=sa.Text, existing_type=sa.VARCHAR
    )

    op.alter_column("python_package_metadata_distutils", "distutils", type_=sa.Text, existing_type=sa.VARCHAR)

    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.alter_column("python_package_metadata", "author", type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column("python_package_metadata", "author_email", type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column("python_package_metadata", "download_url", type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column("python_package_metadata", "home_page", type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column("python_package_metadata", "keywords", type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column("python_package_metadata", "license", type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column("python_package_metadata", "maintainer", type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column("python_package_metadata", "maintainer_email", type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column("python_package_metadata", "metadata_version", type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column("python_package_metadata", "name", type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column("python_package_metadata", "summary", type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column("python_package_metadata", "version", type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column("python_package_metadata", "requires_python", type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column("python_package_metadata", "description", type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column("python_package_metadata", "description_content_type", type_=sa.String, existing_type=sa.VARCHAR)

    op.alter_column("python_package_metadata_classifier", "classifier", type_=sa.String, existing_type=sa.VARCHAR)

    op.alter_column("python_package_metadata_platform", "platform", type_=sa.String, existing_type=sa.VARCHAR)

    op.alter_column(
        "python_package_metadata_supported_platform", "supported_platform", type_=sa.String, existing_type=sa.VARCHAR
    )

    op.alter_column(
        "python_package_metadata_requires_external", "dependency", type_=sa.String, existing_type=sa.VARCHAR
    )

    op.alter_column("python_package_metadata_project_url", "project_url", type_=sa.String, existing_type=sa.VARCHAR)

    op.alter_column(
        "python_package_metadata_provides_extra", "optional_feature", type_=sa.String, existing_type=sa.VARCHAR
    )

    op.alter_column("python_package_metadata_distutils", "distutils", type_=sa.String, existing_type=sa.VARCHAR)
    # ### end Alembic commands ###



"""Delete to refactor Schema for Python Software Stack

Revision ID: 1a8150ac45e0
Revises: 342d45db2dc2
Create Date: 2020-10-09 15:42:56.711181+00:00

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision = "1a8150ac45e0"
down_revision = "342d45db2dc2"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table("external_python_requirements_lock")
    op.drop_table("has_unresolved")
    op.drop_table("advised")
    op.drop_table("python_requirements_lock")
    op.drop_table("adviser_run")
    op.drop_table("python_requirements")
    op.drop_table("pi_conv1d")
    op.drop_table("pi_pybench")
    op.drop_table("provenance_checker_run")
    op.drop_table("pi_conv2d")
    op.drop_table("pi_matmul")
    op.drop_table("inspection_run")
    op.drop_table("python_software_stack")
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "pi_matmul",
        sa.Column("origin", sa.VARCHAR(length=256), autoincrement=False, nullable=False),
        sa.Column("version", sa.VARCHAR(length=256), autoincrement=False, nullable=False),
        sa.Column("overall_score", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=True),
        sa.Column("exit_code", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_utime", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False),
        sa.Column("ru_stime", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False),
        sa.Column("ru_maxrss", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_ixrss", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_idrss", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_isrss", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_minflt", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_majflt", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_nswap", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_inblock", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_oublock", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_msgsnd", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_msgrcv", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_nsignals", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_nvcsw", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_nivcsw", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("id", sa.INTEGER(), autoincrement=True, nullable=False),
        sa.Column("inspection_run_id", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("device", sa.VARCHAR(length=256), autoincrement=False, nullable=False),
        sa.Column("matrix_size", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("dtype", sa.VARCHAR(length=256), autoincrement=False, nullable=False),
        sa.Column("reps", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("elapsed", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False),
        sa.Column("rate", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False),
        sa.Column("component", sa.VARCHAR(length=256), autoincrement=False, nullable=False),
        sa.ForeignKeyConstraint(["inspection_run_id"], ["inspection_run.id"], name="pi_matmul_inspection_run_id_fkey"),
        sa.PrimaryKeyConstraint("id", name="pi_matmul_pkey"),
    )
    op.create_table(
        "pi_conv2d",
        sa.Column("origin", sa.VARCHAR(length=256), autoincrement=False, nullable=False),
        sa.Column("version", sa.VARCHAR(length=256), autoincrement=False, nullable=False),
        sa.Column("overall_score", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=True),
        sa.Column("exit_code", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_utime", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False),
        sa.Column("ru_stime", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False),
        sa.Column("ru_maxrss", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_ixrss", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_idrss", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_isrss", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_minflt", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_majflt", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_nswap", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_inblock", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_oublock", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_msgsnd", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_msgrcv", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_nsignals", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_nvcsw", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_nivcsw", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("id", sa.INTEGER(), autoincrement=True, nullable=False),
        sa.Column("inspection_run_id", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("device", sa.VARCHAR(length=256), autoincrement=False, nullable=False),
        sa.Column("dtype", sa.VARCHAR(length=256), autoincrement=False, nullable=False),
        sa.Column("reps", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("data_format", sa.VARCHAR(length=256), autoincrement=False, nullable=False),
        sa.Column("batch", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("input_height", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("input_width", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("input_channels", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("filter_height", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("filter_width", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("output_channels", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("strides", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("padding", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("elapsed", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False),
        sa.Column("rate", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False),
        sa.Column("component", sa.VARCHAR(length=256), autoincrement=False, nullable=False),
        sa.ForeignKeyConstraint(["inspection_run_id"], ["inspection_run.id"], name="pi_conv2d_inspection_run_id_fkey"),
        sa.PrimaryKeyConstraint("id", name="pi_conv2d_pkey"),
    )
    op.create_table(
        "provenance_checker_run",
        sa.Column("id", sa.INTEGER(), autoincrement=True, nullable=False),
        sa.Column("provenance_checker_document_id", sa.TEXT(), autoincrement=False, nullable=False),
        sa.Column("datetime", postgresql.TIMESTAMP(), autoincrement=False, nullable=False),
        sa.Column("provenance_checker_version", sa.TEXT(), autoincrement=False, nullable=False),
        sa.Column("provenance_checker_name", sa.TEXT(), autoincrement=False, nullable=False),
        sa.Column("origin", sa.TEXT(), autoincrement=False, nullable=True),
        sa.Column("debug", sa.BOOLEAN(), autoincrement=False, nullable=False),
        sa.Column("provenance_checker_error", sa.BOOLEAN(), autoincrement=False, nullable=False),
        sa.Column("duration", sa.INTEGER(), autoincrement=False, nullable=True),
        sa.Column("user_software_stack_id", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.ForeignKeyConstraint(
            ["user_software_stack_id"],
            ["python_software_stack.id"],
            name="provenance_checker_run_user_software_stack_id_fkey",
            ondelete="CASCADE",
        ),
        sa.PrimaryKeyConstraint("id", "user_software_stack_id", name="provenance_checker_run_pkey"),
    )
    op.create_table(
        "pi_pybench",
        sa.Column("component", sa.VARCHAR(length=256), autoincrement=False, nullable=False),
        sa.Column("origin", sa.VARCHAR(length=256), autoincrement=False, nullable=False),
        sa.Column("version", sa.VARCHAR(length=256), autoincrement=False, nullable=False),
        sa.Column("overall_score", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=True),
        sa.Column("exit_code", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_utime", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False),
        sa.Column("ru_stime", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False),
        sa.Column("ru_maxrss", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_ixrss", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_idrss", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_isrss", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_minflt", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_majflt", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_nswap", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_inblock", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_oublock", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_msgsnd", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_msgrcv", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_nsignals", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_nvcsw", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_nivcsw", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("id", sa.INTEGER(), autoincrement=True, nullable=False),
        sa.Column("inspection_run_id", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("rounds", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column(
            "built_in_function_calls_average",
            postgresql.DOUBLE_PRECISION(precision=53),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "built_in_method_lookup_average",
            postgresql.DOUBLE_PRECISION(precision=53),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "compare_floats_average", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False
        ),
        sa.Column(
            "compare_floats_integers_average",
            postgresql.DOUBLE_PRECISION(precision=53),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "compare_integers_average", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False
        ),
        sa.Column(
            "compare_interned_strings_average",
            postgresql.DOUBLE_PRECISION(precision=53),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "compare_longs_average", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False
        ),
        sa.Column(
            "compare_strings_average", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False
        ),
        sa.Column(
            "compare_unicode_average", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False
        ),
        sa.Column(
            "concat_strings_average", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False
        ),
        sa.Column(
            "concat_unicode_average", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False
        ),
        sa.Column(
            "create_instances_average", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False
        ),
        sa.Column(
            "create_new_instances_average",
            postgresql.DOUBLE_PRECISION(precision=53),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "create_strings_with_concat_average",
            postgresql.DOUBLE_PRECISION(precision=53),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "create_unicode_with_concat_average",
            postgresql.DOUBLE_PRECISION(precision=53),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "dict_creation_average", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False
        ),
        sa.Column(
            "dict_with_float_keys_average",
            postgresql.DOUBLE_PRECISION(precision=53),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "dict_with_integer_keys_average",
            postgresql.DOUBLE_PRECISION(precision=53),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "dict_with_string_keys_average",
            postgresql.DOUBLE_PRECISION(precision=53),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column("for_loops_average", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False),
        sa.Column(
            "if_then_else_average", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False
        ),
        sa.Column(
            "list_slicing_average", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False
        ),
        sa.Column(
            "nested_for_loops_average", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False
        ),
        sa.Column(
            "normal_class_attribute_average",
            postgresql.DOUBLE_PRECISION(precision=53),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "normal_instance_attribute_average",
            postgresql.DOUBLE_PRECISION(precision=53),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "python_function_calls_average",
            postgresql.DOUBLE_PRECISION(precision=53),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "python_method_calls_average",
            postgresql.DOUBLE_PRECISION(precision=53),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column("recursion_average", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False),
        sa.Column(
            "second_import_average", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False
        ),
        sa.Column(
            "second_package_import_average",
            postgresql.DOUBLE_PRECISION(precision=53),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "second_submodule_import_average",
            postgresql.DOUBLE_PRECISION(precision=53),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "simple_complex_arithmetic_average",
            postgresql.DOUBLE_PRECISION(precision=53),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "simple_dict_manipulation_average",
            postgresql.DOUBLE_PRECISION(precision=53),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "simple_float_arithmetic_average",
            postgresql.DOUBLE_PRECISION(precision=53),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "simple_int_float_arithmetic_average",
            postgresql.DOUBLE_PRECISION(precision=53),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "simple_integer_arithmetic_average",
            postgresql.DOUBLE_PRECISION(precision=53),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "simple_list_manipulation_average",
            postgresql.DOUBLE_PRECISION(precision=53),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "simple_long_arithmetic_average",
            postgresql.DOUBLE_PRECISION(precision=53),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "small_lists_average", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False
        ),
        sa.Column(
            "small_tuples_average", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False
        ),
        sa.Column(
            "special_class_attribute_average",
            postgresql.DOUBLE_PRECISION(precision=53),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "special_instance_attribute_average",
            postgresql.DOUBLE_PRECISION(precision=53),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "string_mappings_average", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False
        ),
        sa.Column(
            "string_predicates_average", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False
        ),
        sa.Column(
            "string_slicing_average", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False
        ),
        sa.Column("try_except_average", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False),
        sa.Column(
            "try_raise_except_average", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False
        ),
        sa.Column(
            "tuple_slicing_average", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False
        ),
        sa.Column(
            "unicode_mappings_average", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False
        ),
        sa.Column(
            "unicode_predicates_average", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False
        ),
        sa.Column(
            "unicode_properties_average", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False
        ),
        sa.Column(
            "unicode_slicing_average", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False
        ),
        sa.Column("totals_average", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False),
        sa.ForeignKeyConstraint(["inspection_run_id"], ["inspection_run.id"], name="pi_pybench_inspection_run_id_fkey"),
        sa.PrimaryKeyConstraint("id", name="pi_pybench_pkey"),
    )
    op.create_table(
        "pi_conv1d",
        sa.Column("origin", sa.VARCHAR(length=256), autoincrement=False, nullable=False),
        sa.Column("version", sa.VARCHAR(length=256), autoincrement=False, nullable=False),
        sa.Column("overall_score", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=True),
        sa.Column("exit_code", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_utime", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False),
        sa.Column("ru_stime", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False),
        sa.Column("ru_maxrss", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_ixrss", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_idrss", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_isrss", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_minflt", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_majflt", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_nswap", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_inblock", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_oublock", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_msgsnd", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_msgrcv", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_nsignals", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_nvcsw", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("ru_nivcsw", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("id", sa.INTEGER(), autoincrement=True, nullable=False),
        sa.Column("inspection_run_id", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("device", sa.VARCHAR(length=256), autoincrement=False, nullable=False),
        sa.Column("dtype", sa.VARCHAR(length=256), autoincrement=False, nullable=False),
        sa.Column("reps", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("data_format", sa.VARCHAR(length=256), autoincrement=False, nullable=False),
        sa.Column("batch", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("input_width", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("input_channels", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("filter_width", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("output_channels", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("strides", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("padding", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("elapsed", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False),
        sa.Column("rate", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=False),
        sa.Column("component", sa.VARCHAR(length=256), autoincrement=False, nullable=False),
        sa.ForeignKeyConstraint(["inspection_run_id"], ["inspection_run.id"], name="pi_conv1d_inspection_run_id_fkey"),
        sa.PrimaryKeyConstraint("id", name="pi_conv1d_pkey"),
    )
    op.create_table(
        "python_requirements",
        sa.Column("id", sa.INTEGER(), autoincrement=True, nullable=False),
        sa.Column("python_package_requirement_id", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("python_software_stack_id", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.ForeignKeyConstraint(
            ["python_package_requirement_id"],
            ["python_package_requirement.id"],
            name="python_requirements_python_package_requirement_id_fkey",
            ondelete="CASCADE",
        ),
        sa.ForeignKeyConstraint(
            ["python_software_stack_id"],
            ["python_software_stack.id"],
            name="python_requirements_python_software_stack_id_fkey",
            ondelete="CASCADE",
        ),
        sa.PrimaryKeyConstraint(
            "id", "python_package_requirement_id", "python_software_stack_id", name="python_requirements_pkey"
        ),
    )
    op.create_table(
        "adviser_run",
        sa.Column(
            "id",
            sa.INTEGER(),
            server_default=sa.text("nextval('adviser_run_id_seq'::regclass)"),
            autoincrement=True,
            nullable=False,
        ),
        sa.Column("adviser_document_id", sa.TEXT(), autoincrement=False, nullable=False),
        sa.Column("datetime", postgresql.TIMESTAMP(), autoincrement=False, nullable=False),
        sa.Column("adviser_version", sa.TEXT(), autoincrement=False, nullable=False),
        sa.Column("adviser_name", sa.TEXT(), autoincrement=False, nullable=False),
        sa.Column("count", sa.INTEGER(), autoincrement=False, nullable=True),
        sa.Column("limit", sa.INTEGER(), autoincrement=False, nullable=True),
        sa.Column("origin", sa.TEXT(), autoincrement=False, nullable=True),
        sa.Column("debug", sa.BOOLEAN(), autoincrement=False, nullable=False),
        sa.Column("limit_latest_versions", sa.INTEGER(), autoincrement=False, nullable=True),
        sa.Column("adviser_error", sa.BOOLEAN(), autoincrement=False, nullable=False),
        sa.Column(
            "recommendation_type",
            postgresql.ENUM("LATEST", "PERFORMANCE", "SECURITY", "STABLE", "TESTING", name="recommendation_type"),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "requirements_format",
            postgresql.ENUM("PIPENV", name="requirements_format"),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column("duration", sa.INTEGER(), autoincrement=False, nullable=True),
        sa.Column("advised_configuration_changes", sa.BOOLEAN(), autoincrement=False, nullable=False),
        sa.Column("additional_stack_info", sa.BOOLEAN(), autoincrement=False, nullable=False),
        sa.Column("user_software_stack_id", sa.INTEGER(), autoincrement=False, nullable=True),
        sa.Column("external_build_software_environment_id", sa.INTEGER(), autoincrement=False, nullable=True),
        sa.Column("external_hardware_information_id", sa.INTEGER(), autoincrement=False, nullable=True),
        sa.Column("external_run_software_environment_id", sa.INTEGER(), autoincrement=False, nullable=True),
        sa.Column("is_s2i", sa.BOOLEAN(), autoincrement=False, nullable=True),
        sa.Column("need_re_run", sa.BOOLEAN(), autoincrement=False, nullable=True),
        sa.Column("re_run_adviser_id", sa.TEXT(), autoincrement=False, nullable=True),
        sa.Column(
            "source_type",
            postgresql.ENUM("CLI", "KEBECHET", "S2I", "GITHUB_APP", "JUPYTER_NOTEBOOK", name="source_type"),
            autoincrement=False,
            nullable=True,
        ),
        sa.ForeignKeyConstraint(
            ["external_build_software_environment_id"],
            ["external_software_environment.id"],
            name="adviser_run_external_build_software_environment_id_fkey",
            ondelete="CASCADE",
        ),
        sa.ForeignKeyConstraint(
            ["external_hardware_information_id"],
            ["external_hardware_information.id"],
            name="adviser_run_external_hardware_information_id_fkey",
            ondelete="CASCADE",
        ),
        sa.ForeignKeyConstraint(
            ["external_run_software_environment_id"],
            ["external_software_environment.id"],
            name="adviser_run_external_run_software_environment_id_fkey",
            ondelete="CASCADE",
        ),
        sa.ForeignKeyConstraint(
            ["user_software_stack_id"],
            ["python_software_stack.id"],
            name="adviser_run_user_software_stack_id_fkey",
            ondelete="CASCADE",
        ),
        sa.PrimaryKeyConstraint("id", name="adviser_run_pkey"),
        postgresql_ignore_search_path=False,
    )
    op.create_table(
        "python_requirements_lock",
        sa.Column("id", sa.INTEGER(), autoincrement=True, nullable=False),
        sa.Column("python_package_version_id", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("python_software_stack_id", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.ForeignKeyConstraint(
            ["python_package_version_id"],
            ["python_package_version.id"],
            name="python_requirements_lock_python_package_version_id_fkey",
            ondelete="CASCADE",
        ),
        sa.ForeignKeyConstraint(
            ["python_software_stack_id"],
            ["python_software_stack.id"],
            name="python_requirements_lock_python_software_stack_id_fkey",
            ondelete="CASCADE",
        ),
        sa.PrimaryKeyConstraint(
            "id", "python_package_version_id", "python_software_stack_id", name="python_requirements_lock_pkey"
        ),
    )
    op.create_table(
        "python_software_stack",
        sa.Column(
            "id",
            sa.INTEGER(),
            server_default=sa.text("nextval('python_software_stack_id_seq'::regclass)"),
            autoincrement=True,
            nullable=False,
        ),
        sa.Column(
            "software_stack_type",
            postgresql.ENUM("USER", "INSPECTION", "ADVISED", name="software_stack_type", create_type=True),
            autoincrement=False,
            nullable=True,
        ),
        sa.Column("performance_score", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=True),
        sa.Column("overall_score", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=True),
        sa.PrimaryKeyConstraint("id", name="python_software_stack_pkey"),
        postgresql_ignore_search_path=False,
    )
    op.create_table(
        "inspection_run",
        sa.Column("id", sa.INTEGER(), autoincrement=True, nullable=False),
        sa.Column("inspection_document_id", sa.TEXT(), autoincrement=False, nullable=False),
        sa.Column("datetime", postgresql.TIMESTAMP(), autoincrement=False, nullable=True),
        sa.Column("amun_version", sa.TEXT(), autoincrement=False, nullable=True),
        sa.Column("build_requests_cpu", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=True),
        sa.Column(
            "build_requests_memory", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=True
        ),
        sa.Column("run_requests_cpu", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=True),
        sa.Column("run_requests_memory", postgresql.DOUBLE_PRECISION(precision=53), autoincrement=False, nullable=True),
        sa.Column(
            "inspection_sync_state",
            postgresql.ENUM("PENDING", "SYNCED", name="inspection_sync_state"),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column("build_hardware_information_id", sa.INTEGER(), autoincrement=False, nullable=True),
        sa.Column("run_hardware_information_id", sa.INTEGER(), autoincrement=False, nullable=True),
        sa.Column("build_software_environment_id", sa.INTEGER(), autoincrement=False, nullable=True),
        sa.Column("run_software_environment_id", sa.INTEGER(), autoincrement=False, nullable=True),
        sa.Column("dependency_monkey_run_id", sa.INTEGER(), autoincrement=False, nullable=True),
        sa.Column("inspection_software_stack_id", sa.INTEGER(), autoincrement=False, nullable=True),
        sa.Column(
            "inspection_result_number", sa.INTEGER(), server_default=sa.text("0"), autoincrement=False, nullable=False
        ),
        sa.ForeignKeyConstraint(
            ["build_hardware_information_id"],
            ["hardware_information.id"],
            name="inspection_run_build_hardware_information_id_fkey",
            ondelete="CASCADE",
        ),
        sa.ForeignKeyConstraint(
            ["build_software_environment_id"],
            ["software_environment.id"],
            name="inspection_run_build_software_environment_id_fkey",
            ondelete="CASCADE",
        ),
        sa.ForeignKeyConstraint(
            ["dependency_monkey_run_id"],
            ["dependency_monkey_run.id"],
            name="inspection_run_dependency_monkey_run_id_fkey",
            ondelete="CASCADE",
        ),
        sa.ForeignKeyConstraint(
            ["inspection_software_stack_id"],
            ["python_software_stack.id"],
            name="inspection_run_inspection_software_stack_id_fkey",
            ondelete="CASCADE",
        ),
        sa.ForeignKeyConstraint(
            ["run_hardware_information_id"],
            ["hardware_information.id"],
            name="inspection_run_run_hardware_information_id_fkey",
            ondelete="CASCADE",
        ),
        sa.ForeignKeyConstraint(
            ["run_software_environment_id"],
            ["software_environment.id"],
            name="inspection_run_run_software_environment_id_fkey",
            ondelete="CASCADE",
        ),
        sa.PrimaryKeyConstraint("id", name="inspection_run_pkey"),
    )
    op.create_table(
        "advised",
        sa.Column("adviser_run_id", sa.INTEGER(), autoincrement=False, nullable=True),
        sa.Column("python_software_stack_id", sa.INTEGER(), autoincrement=False, nullable=True),
        sa.ForeignKeyConstraint(
            ["adviser_run_id"], ["adviser_run.id"], name="advised_adviser_run_id_fkey", ondelete="CASCADE"
        ),
        sa.ForeignKeyConstraint(
            ["python_software_stack_id"],
            ["python_software_stack.id"],
            name="advised_python_software_stack_id_fkey",
            ondelete="CASCADE",
        ),
    )
    op.create_table(
        "has_unresolved",
        sa.Column("adviser_run_id", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("python_package_version_entity_id", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.ForeignKeyConstraint(
            ["adviser_run_id"], ["adviser_run.id"], name="has_unresolved_adviser_run_id_fkey", ondelete="CASCADE"
        ),
        sa.ForeignKeyConstraint(
            ["python_package_version_entity_id"],
            ["python_package_version_entity.id"],
            name="has_unresolved_python_package_version_entity_id_fkey",
            ondelete="CASCADE",
        ),
        sa.PrimaryKeyConstraint("adviser_run_id", "python_package_version_entity_id", name="has_unresolved_pkey"),
    )
    op.create_table(
        "external_python_requirements_lock",
        sa.Column("id", sa.INTEGER(), autoincrement=True, nullable=False),
        sa.Column("python_package_version_entity_id", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("python_software_stack_id", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.ForeignKeyConstraint(
            ["python_package_version_entity_id"],
            ["python_package_version_entity.id"],
            name="external_python_requirements__python_package_version_entit_fkey",
            ondelete="CASCADE",
        ),
        sa.ForeignKeyConstraint(
            ["python_software_stack_id"],
            ["python_software_stack.id"],
            name="external_python_requirements_lock_python_software_stack_id_fkey",
            ondelete="CASCADE",
        ),
        sa.PrimaryKeyConstraint(
            "id",
            "python_package_version_entity_id",
            "python_software_stack_id",
            name="external_python_requirements_lock_pkey",
        ),
    )
    # ### end Alembic commands ###



"""Added SecurityIndicatorAggregatedRun Table and Aggregated Table

Revision ID: 9aa4e29fa260
Revises: d77154f3c15f
Create Date: 2020-07-03 12:23:50.615984+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "9aa4e29fa260"
down_revision = "d77154f3c15f"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "si_aggregated_run",
        sa.Column("id", sa.Integer(), autoincrement=True, nullable=False),
        sa.Column("si_aggregated_run_document_id", sa.Text(), nullable=False),
        sa.Column("severity_high_confidence_high", sa.Integer(), nullable=False),
        sa.Column("severity_high_confidence_low", sa.Integer(), nullable=False),
        sa.Column("severity_high_confidence_medium", sa.Integer(), nullable=False),
        sa.Column("severity_high_confidence_undefined", sa.Integer(), nullable=False),
        sa.Column("severity_low_confidence_high", sa.Integer(), nullable=False),
        sa.Column("severity_low_confidence_low", sa.Integer(), nullable=False),
        sa.Column("severity_low_confidence_medium", sa.Integer(), nullable=False),
        sa.Column("severity_low_confidence_undefined", sa.Integer(), nullable=False),
        sa.Column("severity_medium_confidence_high", sa.Integer(), nullable=False),
        sa.Column("severity_medium_confidence_low", sa.Integer(), nullable=False),
        sa.Column("severity_medium_confidence_medium", sa.Integer(), nullable=False),
        sa.Column("severity_medium_confidence_undefined", sa.Integer(), nullable=False),
        sa.Column("number_of_analyzed_files", sa.Integer(), nullable=False),
        sa.Column("number_of_files_total", sa.Integer(), nullable=False),
        sa.Column("number_of_files_with_severities", sa.Integer(), nullable=False),
        sa.Column("number_of_filtered_files", sa.Integer(), nullable=False),
        sa.Column("number_of_python_files", sa.Integer(), nullable=False),
        sa.Column("number_of_lines_with_comments_in_python_files", sa.Integer(), nullable=False),
        sa.Column("number_of_blank_lines_in_python_files", sa.Integer(), nullable=False),
        sa.Column("number_of_lines_with_code_in_python_files", sa.Integer(), nullable=False),
        sa.Column("total_number_of_files", sa.Integer(), nullable=False),
        sa.Column("total_number_of_lines", sa.Integer(), nullable=False),
        sa.Column("total_number_of_lines_with_comments", sa.Integer(), nullable=False),
        sa.Column("total_number_of_blank_lines", sa.Integer(), nullable=False),
        sa.Column("total_number_of_lines_with_code", sa.Integer(), nullable=False),
        sa.PrimaryKeyConstraint("id"),
    )
    op.create_table(
        "si_aggregated",
        sa.Column("si_aggregated_run_id", sa.Integer(), nullable=False),
        sa.Column("python_package_version_entity_id", sa.Integer(), nullable=False),
        sa.ForeignKeyConstraint(
            ["python_package_version_entity_id"], ["python_package_version_entity.id"], ondelete="CASCADE"
        ),
        sa.ForeignKeyConstraint(["si_aggregated_run_id"], ["si_aggregated_run.id"], ondelete="CASCADE"),
        sa.PrimaryKeyConstraint("si_aggregated_run_id", "python_package_version_entity_id"),
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table("si_aggregated")
    op.drop_table("si_aggregated_run")
    # ### end Alembic commands ###



"""Sync python interpreters

Revision ID: 74f68dabbb46
Revises: 184e698fe2c2
Create Date: 2019-10-16 13:34:12.694324+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "74f68dabbb46"
down_revision = "184e698fe2c2"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "python_interpreter",
        sa.Column("id", sa.Integer(), autoincrement=True, nullable=False),
        sa.Column("path", sa.String(length=256), nullable=False),
        sa.Column("link", sa.String(length=256), nullable=True),
        sa.Column("version", sa.String(length=256), nullable=True),
        sa.PrimaryKeyConstraint("id"),
    )
    op.create_table(
        "found_python_interpreter",
        sa.Column("id", sa.Integer(), autoincrement=True, nullable=False),
        sa.Column("python_interpreter_id", sa.Integer(), nullable=False),
        sa.Column("package_extract_run_id", sa.Integer(), nullable=False),
        sa.ForeignKeyConstraint(["package_extract_run_id"], ["package_extract_run.id"], ondelete="CASCADE"),
        sa.ForeignKeyConstraint(["python_interpreter_id"], ["python_interpreter.id"], ondelete="CASCADE"),
        sa.PrimaryKeyConstraint("id", "python_interpreter_id", "package_extract_run_id"),
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table("found_python_interpreter")
    op.drop_table("python_interpreter")
    # ### end Alembic commands ###



"""Create index for solved on version id

Revision ID: 7d970baad7f2
Revises: b91c11e75551
Create Date: 2020-01-13 22:40:23.898138+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "7d970baad7f2"
down_revision = "b91c11e75551"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_index("solved_version_id_idx", "solved", ["version_id"], unique=False)
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index("solved_version_id_idx", table_name="solved")
    # ### end Alembic commands ###



"""Recreate indexes for Python package version

Revision ID: b91c11e75551
Revises: 1fbd52a03c73
Create Date: 2020-01-13 21:37:05.476084+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "b91c11e75551"
down_revision = "1fbd52a03c73"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_index(
        "python_package_version_index_idx_00",
        "python_package_version",
        ["package_name", "package_version"],
        unique=False,
    )
    op.drop_index("python_package_version_index_idx_10", table_name="python_package_version")
    op.create_index(
        "python_package_version_index_idx_10",
        "python_package_version",
        ["package_name", "package_version", "os_name"],
        unique=False,
    )
    op.drop_index("python_package_version_index_idx_11", table_name="python_package_version")
    op.create_index(
        "python_package_version_index_idx_11",
        "python_package_version",
        ["package_name", "package_version", "os_version"],
        unique=False,
    )
    op.drop_index("python_package_version_index_idx_12", table_name="python_package_version")
    op.create_index(
        "python_package_version_index_idx_12",
        "python_package_version",
        ["package_name", "package_version", "python_version"],
        unique=False,
    )
    op.drop_index("python_package_version_index_idx_20", table_name="python_package_version")
    op.create_index(
        "python_package_version_index_idx_20",
        "python_package_version",
        ["package_name", "package_version", "os_name", "os_version"],
        unique=False,
    )
    op.drop_index("python_package_version_index_idx_21", table_name="python_package_version")
    op.create_index(
        "python_package_version_index_idx_21",
        "python_package_version",
        ["package_name", "package_version", "os_name", "python_version"],
        unique=False,
    )
    op.drop_index("python_package_version_index_idx_22", table_name="python_package_version")
    op.create_index(
        "python_package_version_index_idx_22",
        "python_package_version",
        ["package_name", "package_version", "os_version", "python_version"],
        unique=False,
    )
    op.drop_index("python_package_version_index_idx_30", table_name="python_package_version")
    op.create_index(
        "python_package_version_index_idx_30",
        "python_package_version",
        ["package_name", "package_version", "os_name", "os_version", "python_version"],
        unique=False,
    )
    op.drop_index("python_package_version_idx", table_name="python_package_version")
    op.drop_index("python_package_version_index_idx_13", table_name="python_package_version")
    op.drop_index("python_package_version_index_idx_23", table_name="python_package_version")
    op.drop_index("python_package_version_index_idx_24", table_name="python_package_version")
    op.drop_index("python_package_version_index_idx_25", table_name="python_package_version")
    op.drop_index("python_package_version_index_idx_31", table_name="python_package_version")
    op.drop_index("python_package_version_index_idx_32", table_name="python_package_version")
    op.drop_index("python_package_version_index_idx_33", table_name="python_package_version")
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_index(
        "python_package_version_index_idx_33",
        "python_package_version",
        ["package_name", "package_version", "python_package_index_id", "os_name", "os_version", "python_version"],
        unique=False,
    )
    op.create_index(
        "python_package_version_index_idx_32",
        "python_package_version",
        [
            "package_name",
            "package_version",
            "python_package_index_id",
            "python_package_index_id",
            "os_version",
            "python_version",
        ],
        unique=False,
    )
    op.create_index(
        "python_package_version_index_idx_31",
        "python_package_version",
        [
            "package_name",
            "package_version",
            "python_package_index_id",
            "python_package_index_id",
            "os_name",
            "python_version",
        ],
        unique=False,
    )
    op.create_index(
        "python_package_version_index_idx_25",
        "python_package_version",
        ["package_name", "package_version", "python_package_index_id", "os_version", "python_version"],
        unique=False,
    )
    op.create_index(
        "python_package_version_index_idx_24",
        "python_package_version",
        ["package_name", "package_version", "python_package_index_id", "os_name", "python_version"],
        unique=False,
    )
    op.create_index(
        "python_package_version_index_idx_23",
        "python_package_version",
        ["package_name", "package_version", "python_package_index_id", "os_name", "os_version"],
        unique=False,
    )
    op.create_index(
        "python_package_version_index_idx_13",
        "python_package_version",
        ["package_name", "package_version", "python_package_index_id", "python_version"],
        unique=False,
    )
    op.create_index(
        "python_package_version_idx",
        "python_package_version",
        ["package_name", "package_version", "python_package_index_id"],
        unique=False,
    )
    op.drop_index("python_package_version_index_idx_30", table_name="python_package_version")
    op.create_index(
        "python_package_version_index_idx_30",
        "python_package_version",
        [
            "package_name",
            "package_version",
            "python_package_index_id",
            "python_package_index_id",
            "os_name",
            "os_version",
        ],
        unique=False,
    )
    op.drop_index("python_package_version_index_idx_22", table_name="python_package_version")
    op.create_index(
        "python_package_version_index_idx_22",
        "python_package_version",
        ["package_name", "package_version", "python_package_index_id", "python_package_index_id", "python_version"],
        unique=False,
    )
    op.drop_index("python_package_version_index_idx_21", table_name="python_package_version")
    op.create_index(
        "python_package_version_index_idx_21",
        "python_package_version",
        ["package_name", "package_version", "python_package_index_id", "python_package_index_id", "os_version"],
        unique=False,
    )
    op.drop_index("python_package_version_index_idx_20", table_name="python_package_version")
    op.create_index(
        "python_package_version_index_idx_20",
        "python_package_version",
        ["package_name", "package_version", "python_package_index_id", "python_package_index_id", "os_name"],
        unique=False,
    )
    op.drop_index("python_package_version_index_idx_12", table_name="python_package_version")
    op.create_index(
        "python_package_version_index_idx_12",
        "python_package_version",
        ["package_name", "package_version", "python_package_index_id", "os_version"],
        unique=False,
    )
    op.drop_index("python_package_version_index_idx_11", table_name="python_package_version")
    op.create_index(
        "python_package_version_index_idx_11",
        "python_package_version",
        ["package_name", "package_version", "python_package_index_id", "os_name"],
        unique=False,
    )
    op.drop_index("python_package_version_index_idx_10", table_name="python_package_version")
    op.create_index(
        "python_package_version_index_idx_10",
        "python_package_version",
        ["package_name", "package_version", "python_package_index_id", "python_package_index_id"],
        unique=False,
    )
    op.drop_index("python_package_version_index_idx_00", table_name="python_package_version")
    # ### end Alembic commands ###



"""Enable nullable limit_latest_versions

Revision ID: 1ee67d9a7861
Revises: 9168881dd125
Create Date: 2019-09-24 11:00:29.326556+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "1ee67d9a7861"
down_revision = "9168881dd125"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.alter_column("adviser_run", "limit_latest_versions", existing_type=sa.INTEGER(), nullable=True)
    op.create_unique_constraint(None, "python_package_version_entity", ["id"])
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_constraint(None, "python_package_version_entity", type_="unique")
    op.alter_column("adviser_run", "limit_latest_versions", existing_type=sa.INTEGER(), nullable=False)
    # ### end Alembic commands ###
